==> pur-api-1.2.3.306-zyyy-20251104.115533-1-sources.jar: com/elitesland/pur/dto/rns/PurRnsCreateRpcParam.java <==
package com.elitesland.pur.dto.rns;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.List;

/**
 * .
 *
 * @author Kaiser（wang shao）
 * @date 2025/11/3 周一
 */
@Getter
@Setter
public class PurRnsCreateRpcParam implements Serializable {
    @Serial
    private static final long serialVersionUID = 6792389666256223517L;

    @ApiModelProperty(value = "公司ID", required = true)
    private Long ouId;
    private String ouCode;

    @ApiModelProperty("部门ID")
    private Long buId;
    @ApiModelProperty("部门编码")
    private String buCode;

    @ApiModelProperty(value = "采购场景类型")
    private Long sceneTypeId;

    @ApiModelProperty(value = "退货人员工ID")
    private Long docEmpId;
    private String docEmpName;

    @ApiModelProperty(value = "单据日期")
    private LocalDateTime docDate;

    @ApiModelProperty(value = "供应商ID", required = true)
    private Long suppId;
    @ApiModelProperty("供应商联系人")
    private String suppContactName;
    @ApiModelProperty("供应商联系电话")
    private String suppContactTel;
    @ApiModelProperty("供应商联系人邮箱")
    private String suppContactEmail;
    @ApiModelProperty("国家编码")
    private String country;
    @ApiModelProperty("省编码")
    private String province;
    @ApiModelProperty("市编码")
    private String city;
    @ApiModelProperty("区县编码")
    private String county;
    @ApiModelProperty("退货详细地址")
    private String returnAddr;

    @ApiModelProperty(value = "仓库ID", required = true)
    private Long whId;
    private String whCode;
    @ApiModelProperty("功能区 [UDC]yst-inv:FUNC_TYPE")
    private String deter2;

    @ApiModelProperty("记账币种")
    private String homeCurr;
    @ApiModelProperty("交易币种")
    private String currCode;

    @ApiModelProperty("汇率")
    private BigDecimal currRate;

    @ApiModelProperty(value = "付款协议编码")
    private String protocolCode;

    @ApiModelProperty("备注")
    private String remark;

    @ApiModelProperty(value = "关联单据类别 [UDC]yst-supp:DOC_CLS", required = true)
    private String relateDocCls;
    @ApiModelProperty("关联单据类型")
    private String relateDocType;
    @ApiModelProperty(value = "关联单据ID", required = true)
    private Long relateDocId;
    @ApiModelProperty(value = "关联单据编号", required = true)
    private String relateDocNo;

    @ApiModelProperty(value = "退货明细列表", required = true)
    private List<PurRnsDCreateRpcParam> purRnsDVOList;
}

==> pur-api-1.2.3.335-zyyy-20251107.102327-1-sources.jar: com/elitesland/pur/dto/rns/PurRnsCreateRpcParam.java <==
package com.elitesland.pur.dto.rns;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.List;

/**
 * .
 *
 * @author Kaiser（wang shao）
 * @date 2025/11/3 周一
 */
@Getter
@Setter
public class PurRnsCreateRpcParam implements Serializable {
    @Serial
    private static final long serialVersionUID = 6792389666256223517L;

    @ApiModelProperty(value = "公司ID", required = true)
    private Long ouId;
    private String ouCode;

    @ApiModelProperty("部门ID")
    private Long buId;
    @ApiModelProperty("部门编码")
    private String buCode;

    @ApiModelProperty(value = "采购场景类型")
    private Long sceneTypeId;

    @ApiModelProperty(value = "退货人员工ID")
    private Long docEmpId;
    private String docEmpName;

    @ApiModelProperty(value = "单据日期")
    private LocalDateTime docDate;

    @ApiModelProperty(value = "供应商ID", required = true)
    private Long suppId;
    @ApiModelProperty("供应商联系人")
    private String suppContactName;
    @ApiModelProperty("供应商联系电话")
    private String suppContactTel;
    @ApiModelProperty("供应商联系人邮箱")
    private String suppContactEmail;
    @ApiModelProperty("国家编码")
    private String country;
    @ApiModelProperty("省编码")
    private String province;
    @ApiModelProperty("市编码")
    private String city;
    @ApiModelProperty("区县编码")
    private String county;
    @ApiModelProperty("退货详细地址")
    private String returnAddr;

    @ApiModelProperty(value = "仓库ID", required = true)
    private Long whId;
    private String whCode;
    @ApiModelProperty("功能区 [UDC]yst-inv:FUNC_TYPE")
    private String deter2;

    @ApiModelProperty("记账币种")
    private String homeCurr;
    @ApiModelProperty("交易币种")
    private String currCode;

    @ApiModelProperty("汇率")
    private BigDecimal currRate;

    @ApiModelProperty(value = "付款协议编码", required = true)
    private String protocolCode;

    @ApiModelProperty("备注")
    private String remark;

    @ApiModelProperty(value = "关联单据类别 [UDC]yst-supp:DOC_CLS", required = true)
    private String relateDocCls;
    @ApiModelProperty("关联单据类型")
    private String relateDocType;
    @ApiModelProperty(value = "关联单据ID", required = true)
    private Long relateDocId;
    @ApiModelProperty(value = "关联单据编号", required = true)
    private String relateDocNo;

    @ApiModelProperty(value = "退货明细列表", required = true)
    private List<PurRnsDCreateRpcParam> purRnsDVOList;
}
